@@ -211,7 +211,7 @@ class AthenaClient:
     def save_data(self, data, file_name, s3_path):
         """Returns records from a table"""
         try:
-            d = json.dumps(data.to_dict(orient='records'))
+            d = data.to_dict(orient='records')
             payload = json.dumps({"user_name": self._user_name, "role_id": self._user_role, "file_name": file_name,
                                   "s3_bucket": s3_path, "data": d})
             print(payload)
